@@ -45,7 +45,7 @@ class ArtifactFormat(SubDir):
 
     @cachedmethod(lambda self: self._is_reserved_cache)
     def _is_reserved_file(self, path, *, resolve=False):
-        digests = self._digest_path()
+        digests = self.digest_path()
         dirty = self._dirty_path()
         if resolve:
             digests = digests.resolve()
@@ -80,7 +80,7 @@ class ArtifactFormat(SubDir):
 
     def get_digests(self) -> Dict[str, str]:
         try:
-            return json.loads(self._digest_path().read_text())
+            return json.loads(self.digest_path().read_text())
         except FileNotFoundError:
             if self.name != "container":
                 return {}
@@ -91,7 +91,7 @@ class ArtifactFormat(SubDir):
         except (OSError, ValueError):
             return {}
 
-    def _digest_path(self) -> Path:
+    def digest_path(self) -> Path:
         return self._path / ".digests"
 
     async def add_file(
@@ -123,7 +123,7 @@ class ArtifactFormat(SubDir):
         # update digests file
         digests = self.get_digests()
         digests[relpath] = digest
-        self._digest_path().write_text(json.dumps(digests))
+        self.digest_path().write_text(json.dumps(digests, sort_keys=True))
 
     def _dirty_path(self) -> Path:
         return self._path / ".dirty"
@@ -209,4 +209,4 @@ class ArtifactFormat(SubDir):
                 blob.parent.mkdir(mode=0o755, parents=True, exist_ok=True)
                 os.link(fpath, blob)
 
-        self._digest_path().write_text(json.dumps(new_digests))
+        self.digest_path().write_text(json.dumps(new_digests, sort_keys=True))
