@@ -110,7 +110,7 @@ class Version(SubDir):
 
     def is_released(self) -> bool:
         for fmt in self.get_formats():
-            released_path = fmt.path().resolve().parent.parent / ".released"
+            released_path = fmt.path().resolve().parent / ".released"
             if released_path.is_file():
                 return True
         return False
